@@ -18,7 +18,7 @@ from flask import request, send_file
 import arcor2_build
 from arcor2 import json
 from arcor2.cached import CachedProject, CachedScene
-from arcor2.clients import persistent_storage as ps
+from arcor2.clients import project_service as ps
 from arcor2.data.common import Project, ProjectSources, Scene
 from arcor2.data.execution import PackageMeta
 from arcor2.data.object_type import Models, ObjectModel, ObjectType
@@ -243,7 +243,10 @@ def project_publish(project_id: str) -> RespT:
     """Publish project
     ---
     get:
-      description: Get zip file with execution package. To be used by the Execution service.
+      tags:
+        - Build
+      summary: Get zip file with execution package. To be used by the Execution service.
+      operationId: ProjectPublish
       parameters:
         - in: path
           name: project_id
@@ -260,17 +263,24 @@ def project_publish(project_id: str) -> RespT:
           description: Package name
       responses:
         200:
-          description: Ok
+          description: Returns archive of the execution package (.zip).
           content:
             application/zip:
                 schema:
                   type: string
                   format: binary
-                  example: The archive of execution package (.zip)
         404:
             description: Project ID or some of the required items was not found.
+            content:
+              application/json:
+                schema:
+                  type: string
         501:
             description: Project invalid.
+            content:
+              application/json:
+                schema:
+                  type: string
     """
 
     return _publish(project_id, request.args.get("packageName", default="N/A"))
@@ -294,33 +304,41 @@ def project_import() -> RespT:
     """Imports a project from execution package.
     ---
     put:
-      description: Imports a project from execution package.
+      tags:
+        - Build
+      summary: Imports a project from execution package.
+      operationId: ProjectImport
       parameters:
             - in: query
               name: overwriteScene
               schema:
                 type: boolean
                 default: false
+              description: overwrite Scene
             - in: query
               name: overwriteProject
               schema:
                 type: boolean
                 default: false
+              description: overwrite Project
             - in: query
               name: overwriteObjectTypes
               schema:
                 type: boolean
                 default: false
+              description: overwrite ObjectTypes
             - in: query
               name: overwriteProjectSources
               schema:
                 type: boolean
                 default: false
+              description: overwrite ProjectSources
             - in: query
               name: overwriteCollisionModels
               schema:
                 type: boolean
                 default: false
+              description: overwrite collision models
       requestBody:
               content:
                 multipart/form-data:
